@@ -437,5 +437,21 @@
         <source>Connection closed</source>
         <translation>Соединение закрыто</translation>
     </message>
+    <message>
+        <source>The server certificate doesn&apos;t contain valid data or expired !</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The authenticity of host &apos;%1&apos; can&apos;t be established.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to continue connecting ?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>SHA1 Fingerprint: %1.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
